==> QupZilla-1.3.5.tar.gz: QupZilla-1.3.5/src/plugins/PIM/translations/es_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es_VE">
<context>
    <name>PIM_Handler</name>
    <message>
        <location filename="../PIM_handler.cpp" line="59"/>
        <source>Last Name</source>
        <translation type="unfinished">Apellido</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="60"/>
        <source>First Name</source>
        <translation type="unfinished">Nombre</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="61"/>
        <source>E-mail</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="62"/>
        <source>Mobile</source>
        <translation type="unfinished">Telefono movil</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="63"/>
        <source>Phone</source>
        <translation type="unfinished">Telefono fijo</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="64"/>
        <source>Address</source>
        <translation type="unfinished">Direccion</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="65"/>
        <source>City</source>
        <translation type="unfinished">Ciudad</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="66"/>
        <source>ZIP Code</source>
        <translation type="unfinished">Codigo postal</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="67"/>
        <source>State/Region</source>
        <translation type="unfinished">Estado</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="68"/>
        <source>Country</source>
        <translation type="unfinished">Pais</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="69"/>
        <source>Home Page</source>
        <translation type="unfinished">Sitio Web</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="70"/>
        <source>Custom 1</source>
        <translation type="unfinished">Complementaria 1</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="71"/>
        <source>Custom 2</source>
        <translation type="unfinished">Complementaria 2</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="72"/>
        <source>Custom 3</source>
        <translation type="unfinished">Complementaria 3</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="110"/>
        <source>Insert Personal Information</source>
        <translation type="unfinished">Ingrese informacion personal</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="124"/>
        <source>Edit</source>
        <translation type="unfinished">Modificar</translation>
    </message>
</context>
<context>
    <name>PIM_Settings</name>
    <message>
        <location filename="../PIM_settings.ui" line="14"/>
        <source>PIM Settings</source>
        <translation type="unfinished">Configuracion PIM</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="42"/>
        <source>&lt;h2&gt;Personal Information Manager&lt;/h2&gt;</source>
        <translation type="unfinished">&lt;h2&gt;Manegador de Informacion Personal (PIM)&lt;/h2&gt;</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="64"/>
        <source>Your personal information that will be used on webpages.</source>
        <translation type="unfinished">Su informacion personal que sera usada en paginas de internet.</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="76"/>
        <source>Phone:</source>
        <translation type="unfinished">Telefono :</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="89"/>
        <source>Address:</source>
        <translation type="unfinished">Direccion:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="99"/>
        <source>Last Name:</source>
        <translation type="unfinished">Apellido:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="112"/>
        <source>First Name:</source>
        <translation type="unfinished">Nombre:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="128"/>
        <source>Mobile Phone:</source>
        <translation type="unfinished">Telefono movil :</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="138"/>
        <source>City:</source>
        <translation type="unfinished">Ciudad:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="151"/>
        <source>E-mail:</source>
        <translation>E-mail :</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="167"/>
        <source>ZIP Code:</source>
        <translation type="unfinished">Codigo postal :</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="180"/>
        <source>State/Region:</source>
        <translation type="unfinished">Estado:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="193"/>
        <source>Country:</source>
        <translation type="unfinished">Pais:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="206"/>
        <source>Home Page:</source>
        <translation type="unfinished">Sitio Web :</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="219"/>
        <source>Custom 1:</source>
        <translation type="unfinished">Complementaria 1:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="232"/>
        <source>Custom 2:</source>
        <translation type="unfinished">Complementaria 2:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="245"/>
        <source>Custom 3:</source>
        <translation type="unfinished">Complementaria 3:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="260"/>
        <source>&lt;b&gt;Note:&lt;/b&gt; Press Ctrl+ENTER to autofill form fields for which QupZilla finds personal entries.</source>
        <translation type="unfinished">&lt;b&gt;Nota:&lt;/b&gt; Presiona Ctrl+ENTER para autorellenar los campos los cuales QupZilla encuentre la informacion.</translation>
    </message>
</context>
</TS>

==> QupZilla-1.4.3.tar.gz: QupZilla-1.4.3/src/plugins/PIM/translations/es_ES.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_ES" version="2.0">
<context>
    <name>PIM_Handler</name>
    <message>
        <location filename="../PIM_handler.cpp" line="60"/>
        <source>Last Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="61"/>
        <source>First Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="62"/>
        <source>E-mail</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="63"/>
        <source>Mobile</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="64"/>
        <source>Phone</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="65"/>
        <source>Address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="66"/>
        <source>City</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="67"/>
        <source>ZIP Code</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="68"/>
        <source>State/Region</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="69"/>
        <source>Country</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="70"/>
        <source>Home Page</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="71"/>
        <source>Custom 1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="72"/>
        <source>Custom 2</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="73"/>
        <source>Custom 3</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="115"/>
        <source>Insert Personal Information</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="136"/>
        <source>Edit</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PIM_Settings</name>
    <message>
        <location filename="../PIM_settings.ui" line="14"/>
        <source>PIM Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="42"/>
        <source>&lt;h2&gt;Personal Information Manager&lt;/h2&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="64"/>
        <source>Your personal information that will be used on webpages.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="76"/>
        <source>First Name:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="89"/>
        <source>Last Name:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="102"/>
        <source>E-mail:</source>
        <translation>E-mail :</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="115"/>
        <source>Phone:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="128"/>
        <source>Mobile Phone:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="141"/>
        <source>Address:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="154"/>
        <source>City:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="167"/>
        <source>ZIP Code:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="180"/>
        <source>State/Region:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="193"/>
        <source>Country:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="206"/>
        <source>Home Page:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="219"/>
        <source>Custom 1:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="232"/>
        <source>Custom 2:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="245"/>
        <source>Custom 3:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="260"/>
        <source>&lt;b&gt;Note:&lt;/b&gt; Press Ctrl+ENTER to autofill form fields for which QupZilla finds personal entries.</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
